Index: net/quic/quic_connection.h |
diff --git a/net/quic/quic_connection.h b/net/quic/quic_connection.h |
index 7b4f0a094441affbfa8561b849c93b4048530021..b6073014e8c3d2c92ff27988cbc8559200a2de4b 100644 |
--- a/net/quic/quic_connection.h |
+++ b/net/quic/quic_connection.h |
@@ -519,8 +519,8 @@ class NET_EXPORT_PRIVATE QuicConnection |
// Returns true if the connection has queued packets or frames. |
bool HasQueuedData() const; |
- // Sets the overall and idle state connection timeouts. |
- void SetNetworkTimeouts(QuicTime::Delta overall_timeout, |
+ // Sets the handshake and idle state connection timeouts. |
+ void SetNetworkTimeouts(QuicTime::Delta handshake_timeout, |
QuicTime::Delta idle_timeout); |
// If the connection has timed out, this will close the connection. |
@@ -947,10 +947,10 @@ class NET_EXPORT_PRIVATE QuicConnection |
// An alarm that fires when an FEC packet should be sent. |
QuicArenaScopedPtr<QuicAlarm> fec_alarm_; |
- // Network idle time before we kill of this connection. |
+ // Network idle time before this connection is closed. |
QuicTime::Delta idle_network_timeout_; |
- // Overall connection timeout. |
- QuicTime::Delta overall_connection_timeout_; |
+ // The connection will wait this long for the handshake to complete. |
+ QuicTime::Delta handshake_timeout_; |
// Statistics for this session. |
QuicConnectionStats stats_; |